Setting up the Course Software Environment (Due June 6, 2015 at 00:00 UTC) | CS100.1x Courseware | edX

Skip to main content
Help

## edX Help

For questions on course lectures, homework, tools, or materials for this course, post in the course discussion forum.

Have general questions about edX? You can find lots of helpful information in the edX FAQ.

Have a question about something specific? You can contact the edX general support team directly:

Report a problem Make a suggestion Ask a question

Please note: The edX support team is English speaking. While we will do our best to address your inquiry in any language, our responses will be in English.

Briefly describe your issue* Tell us the details* Include error messages, steps which lead to the issue, etc

## Thank You!

Thank you for your inquiry or feedback. We typically respond to a request within one business day (Monday to Friday, 13:00 UTC to 21:00 UTC.) In the meantime, please review our detailed FAQs where most questions have already been answered.

<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_47e86c96e64346b78f657fb599739857" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/c1bd649f536e469eb1abd3f05371fa6b"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_c1bd649f536e469eb1abd3f05371fa6b" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h1>Introduction</h1> <p>In this course, you will learn how to write and debug Python Spark (pySpark) programs in four weekly lab exercises. We expect everyone to use the same software development environment. Our software development environment uses a Virtual Machine (VM) to simplify the installation process and provide all students with the same development environment. You will need to first install two free software packages (VirtualBox and Vagrant), and then download and install our VM image. In this segment, we will walk you through the process of downloading and installing the required software and VM image, and of running a test&nbsp;pySpark IPython notebook.</p> <p><em>Note: The total size of all the files you will need to download is less than&nbsp;1 GB.</em></p> <h1>Hardware and Software Prerequisites</h1> <p>You will need a machine that meets certain minimum hardware requirements and is running a supported operating system. <em>Note:&nbsp;Other configurations may work fine, but we will not be able to provide official support for them.</em>&nbsp;</p> <h2>Minimum Hardware REquirements</h2> <p>You should use a machine with the following minimum hardware requirements:</p> <ul> <ul> <li>Free disk space: 3.5 GB&nbsp;</li> <li>RAM memory: 2.5 GB (4+ GB preferred)</li> <li>Processor: &nbsp;Any recent Intel or AMD multicore processor should be sufficient.</li> </ul> </ul> <h2></h2> <h2><span style="line-height: 1.6;">Supported Operating Systems</span></h2> <p><span style="line-height: 1.6;">We support the following Operating Systems:</span></p> <ul> <ul> <ul> <li>64-bit (preferred) Windows 7 or later</li> <li>64-bit (preferred) Mac OS X 10.9.5 or later</li> <li>64-bit (preferred) Linux (CentOS 6 or later, or&nbsp;Ubuntu 14.04 or&nbsp;later)</li> <li>32-bit Windows 7 or later</li> <li>32-bit&nbsp;Linux&nbsp;(CentOS 6 or later, or&nbsp;Ubuntu 14.04 or&nbsp;later)</li> </ul> </ul> </ul> <p><span style="line-height: 25px;"><i>NOTE for Linux users: Based on our testing, please make sure you are using Vagrant 1.7 or newer with Linux. The default Vagrant version packaged with most Linux distributions does not seem to work properly with our&nbsp;course software.&nbsp;</i></span></p> <p><span style="line-height: 1.6;">(Optional) For the best performance with VirtualBox, we recommend using a machine that supports hardware virtualization features: Intel VT-X or AMD AMD-V. </span><em style="line-height: 1.6;">Note that on many systems, the hardware virtualization features first need to be enabled in the BIOS before VirtualBox can use them.</em></p> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_0e63cd3c8d314b1d817b9dfe019fecf1" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/c28a781726254a26a68140b24aa97331"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_c28a781726254a26a68140b24aa97331" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h1>Installing the Required&nbsp;Software Packages</h1> <h2>REQUIRED SOFTWARE PACKAGES</h2> <p style="font-size: 16px;">There are two required free software packages:</p> <ul> <li>Oracle's&nbsp;<a href="https://www.virtualbox.org" target="_blank">Virtual Box</a></li> <li><a href="https://www.vagrantup.com" target="_blank">Vagrant</a>&nbsp;automatic VM configuration</li> </ul> <p style="font-size: 16px;"><em>Note: If you already have either software package installed, makes sure that the versions are&nbsp;VirtualBox 4.3.28 (or later) and&nbsp;Vagrant 1.7.2 (or later).</em></p> <p style="font-size: 16px;">The following&nbsp;video segments walk you through the steps to download and install the required software packages&nbsp;on your machine, and to run your first Apache Spark notebook.</p> <p></p> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_0aba1754164d431e86e39de0293d8ef1" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/7dd654c4180f4c1bb2f88c5627f2db93"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_7dd654c4180f4c1bb2f88c5627f2db93" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h1>Downloading and Installing VirtualBox</h1> <p>Go to the <a href="https://www.virtualbox.org/wiki/Downloads" target="_blank">Downloads</a>&nbsp;page for VirtualBox and download the appropriate version for your operating system.&nbsp;</p> <p>While you wait for your&nbsp;download to complete, watch the appropriate video (below) for your system to see the VirtualBox download and installation process.&nbsp;</p> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS100.1x/video/d34dee586d424ccd981621ba9ead9631"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_d34dee586d424ccd981621ba9ead9631" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>VirtualBox for Windows</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-d34dee586d424ccd981621ba9ead9631" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "0fPt7zrAW1k", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d34dee586d424ccd981621ba9ead9631/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V002400_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:0fPt7zrAW1k", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d34dee586d424ccd981621ba9ead9631/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d34dee586d424ccd981621ba9ead9631/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-d34dee586d424ccd981621ba9ead9631" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-d34dee586d424ccd981621ba9ead9631"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-d34dee586d424ccd981621ba9ead9631" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-d34dee586d424ccd981621ba9ead9631">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-d34dee586d424ccd981621ba9ead9631" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-d34dee586d424ccd981621ba9ead9631">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V002400_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d34dee586d424ccd981621ba9ead9631/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS100.1x/video/30f36fd010ae4d75a36fd394f638c23a"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_30f36fd010ae4d75a36fd394f638c23a" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>VirtualBox for Mac OS X</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-30f36fd010ae4d75a36fd394f638c23a" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "3atHHNa2UwI", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_30f36fd010ae4d75a36fd394f638c23a/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013700_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:3atHHNa2UwI", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_30f36fd010ae4d75a36fd394f638c23a/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_30f36fd010ae4d75a36fd394f638c23a/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-30f36fd010ae4d75a36fd394f638c23a" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-30f36fd010ae4d75a36fd394f638c23a"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-30f36fd010ae4d75a36fd394f638c23a" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-30f36fd010ae4d75a36fd394f638c23a">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-30f36fd010ae4d75a36fd394f638c23a" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-30f36fd010ae4d75a36fd394f638c23a">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013700_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_30f36fd010ae4d75a36fd394f638c23a/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-3" data-id="i4x://BerkeleyX/CS100.1x/video/03d35412087c4eaa853e75dd23a2f242"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_03d35412087c4eaa853e75dd23a2f242" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>VirtualBox for Linux</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-03d35412087c4eaa853e75dd23a2f242" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "1_4USzcKx6g", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_03d35412087c4eaa853e75dd23a2f242/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V012100_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:1_4USzcKx6g", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_03d35412087c4eaa853e75dd23a2f242/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_03d35412087c4eaa853e75dd23a2f242/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-03d35412087c4eaa853e75dd23a2f242" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-03d35412087c4eaa853e75dd23a2f242"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-03d35412087c4eaa853e75dd23a2f242" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-03d35412087c4eaa853e75dd23a2f242">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-03d35412087c4eaa853e75dd23a2f242" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-03d35412087c4eaa853e75dd23a2f242">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V012100_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_03d35412087c4eaa853e75dd23a2f242/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-4" data-id="i4x://BerkeleyX/CS100.1x/html/56e4b0df2e734932995ac9a0b413b587"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_56e4b0df2e734932995ac9a0b413b587" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h2>FAQS FOR WINDOWS</h2> <p style="font-size: 16px;">When attempting to start VirtualBox, you may encounter the following error:</p> <dl class="codebox" style="margin: 0px; padding: 0px; border: 1px solid #c9d2d8; font-size: 13px; color: #333333; font-family: 'Lucida Grande', 'Trebuchet MS', Verdana, Helvetica, Arial, sans-serif; line-height: 18.200000762939453px;"><dd style="margin: 0px; padding: 0px;"><code style="margin: 2px 0px; padding-top: 5px; overflow: auto; display: block; height: auto; font-size: 0.9em; font-family: Monaco, 'Andale Mono', 'Courier New', Courier, mono; line-height: 1.3em; color: #2e8b57; max-height: 200px;">VirtualBox - Critical Error<br style="margin: 0px; padding: 0px;" />Failed to create the VirtualBox COM object.<br style="margin: 0px; padding: 0px;" />The application will now terminate.<br style="margin: 0px; padding: 0px;" />Callee RC: E_NOINTERFACE (0x80004002)</code></dd></dl> <p style="font-size: 16px;">If you encounter this error, you may not have installed VirtualBox as Administrator. You should perform the following steps:</p> <ul> <ul> <li><span style="line-height: 1.6em;">Uninstall VirtualBox</span></li> <li><span style="line-height: 1.6em;">Reboot your machine</span></li> <li><span style="line-height: 1.6em;">Reinstall VirtualBox by right-clicking on the installation file and selecting "Run as Administrator"</span></li> <li><span style="line-height: 1.6em;">Once the installation completes, select "Start Menu-&gt;Oracle VM VirtualBox"</span></li> <li><span style="line-height: 1.6em;">Right click on "Oracle VM VirtualBox" and select "Properties" </span></li> <li><span style="line-height: 1.6em;">Navigate to the "Compatibility" tab</span></li> <li><span style="line-height: 1.6em;">In the Compatibility mode box, click the checkbox for &nbsp;"Run this program in compatibility mode for:" and select "Windows XP (Service Pack 3)"</span></li> <li><span style="line-height: 1.6em;">In the Priviledge Level box, click on the check box for&nbsp;</span><span style="line-height: 25.600000381469727px;">"Run this program as an administrator"</span></li> <li><span style="line-height: 25.600000381469727px;">Click on "Change settings for all users" and make sure that both the checkboxes for&nbsp;</span><span style="line-height: 25.600000381469727px;">"Run this program in compatibility mode for:" and&nbsp;</span><span style="line-height: 25.600000381469727px;">"Run this program as an administrator" are set.</span></li> </ul> </ul> <p style="font-size: 16px;"></p> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_daa8a13846474b4f9c73540fa7d9fdc3" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/50eff4b1961f445aa5e06c8371610ac5"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_50eff4b1961f445aa5e06c8371610ac5" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h1>Downloading and Installing Vagrant</h1> <p style="text-rendering: optimizelegibility; margin-top: 0px; margin-right: 0px; margin-left: 0px; padding: 0px; border: 0px; outline: 0px; font-family: 'Open Sans', 'Helvetica Neue', Helvetica, Arial, sans-serif; font-size: 16px; vertical-align: baseline; color: #4c4c4c;">Go to the <a href="https://www.vagrantup.com/downloads.html" target="_blank">Downloads</a>&nbsp;page for Vagrant&nbsp;and download the appropriate version for your operating system.&nbsp;</p> <p style="text-rendering: optimizelegibility; margin-right: 0px; margin-left: 0px; padding: 0px; border: 0px; outline: 0px; font-family: 'Open Sans', 'Helvetica Neue', Helvetica, Arial, sans-serif; font-size: 16px; vertical-align: baseline; color: #4c4c4c;">While you wait for your&nbsp;download to complete, watch the appropriate video (below) for your system to see the Vagrant&nbsp;download and installation process.&nbsp;</p> <p style="font-size: 16px;"><span style="line-height: 25px;"><i>NOTE for Linux users: Based on our testing, please make sure you are using Vagrant 1.7 or newer with Linux. The default Vagrant version packaged with most Linux distributions does not seem to work properly with&nbsp;our&nbsp;course software.&nbsp;</i></span></p> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS100.1x/video/d9db9736e0f7439498a625943e931d9f"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_d9db9736e0f7439498a625943e931d9f" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Vagrant for Windows</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-d9db9736e0f7439498a625943e931d9f" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "phsPValZUOE", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d9db9736e0f7439498a625943e931d9f/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V002300_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:phsPValZUOE", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d9db9736e0f7439498a625943e931d9f/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d9db9736e0f7439498a625943e931d9f/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-d9db9736e0f7439498a625943e931d9f" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-d9db9736e0f7439498a625943e931d9f"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-d9db9736e0f7439498a625943e931d9f" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-d9db9736e0f7439498a625943e931d9f">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-d9db9736e0f7439498a625943e931d9f" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-d9db9736e0f7439498a625943e931d9f">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V002300_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_d9db9736e0f7439498a625943e931d9f/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS100.1x/html/337ae07d49a3432a9cb5e43873dabb23"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_337ae07d49a3432a9cb5e43873dabb23" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <p><span style="font-family: 'Open Sans', Verdana, Arial, Helvetica, sans-serif;">If you encounter the Windows error:&nbsp;</span>&ldquo;Installation Directory must be on a local hard drive&rdquo;, this is a permissions error and you need to force the installer to run with administrator privileges.</p> <p><span style="font-family: 'Open Sans', Verdana, Arial, Helvetica, sans-serif;">To do so:</span></p> <ol><ol> <li><span style="font-size: 1em; line-height: 1.6em;">Locate the Vagrant MSI&nbsp;installer file that you downloaded.</span></li> <li>While holding down the Shift key on the keyboard, right-click on the Vagrant&nbsp;MSI, then choose&nbsp;<strong>Copy As Path</strong>.</li> <li>Go to Start &gt; All Programs &gt; Accessories.</li> <li>Right-click on&nbsp;<strong>Command Prompt</strong>&nbsp;and choose&nbsp;<strong>Run As Administrator</strong>. This should open a command prompt window, labeled "Administrator:".</li> <li>In the Command Prompt window, type&nbsp;<strong>msiexec /i&nbsp;</strong>(you need to enter a single space after "/i").</li> <li>Right-click in the Command Prompt window, then choose&nbsp;<strong>Paste</strong>. This should paste the path to the MSI file that you copied in Step 2 above.</li> <li>Press Enter to run the command.</li> </ol></ol> </div> </div> <div class="vert vert-3" data-id="i4x://BerkeleyX/CS100.1x/video/f5f7eadf19df4a15bf90c52f3c02ad17"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_f5f7eadf19df4a15bf90c52f3c02ad17" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Vagrant for Mac OS X</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-f5f7eadf19df4a15bf90c52f3c02ad17" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "hPmawNk2XQw", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_f5f7eadf19df4a15bf90c52f3c02ad17/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013900_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:hPmawNk2XQw", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_f5f7eadf19df4a15bf90c52f3c02ad17/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_f5f7eadf19df4a15bf90c52f3c02ad17/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-f5f7eadf19df4a15bf90c52f3c02ad17" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-f5f7eadf19df4a15bf90c52f3c02ad17"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-f5f7eadf19df4a15bf90c52f3c02ad17" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-f5f7eadf19df4a15bf90c52f3c02ad17">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-f5f7eadf19df4a15bf90c52f3c02ad17" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-f5f7eadf19df4a15bf90c52f3c02ad17">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013900_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_f5f7eadf19df4a15bf90c52f3c02ad17/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-4" data-id="i4x://BerkeleyX/CS100.1x/video/37f0e9055bec4a05b11eef7795e8887a"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_37f0e9055bec4a05b11eef7795e8887a" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Vagrant for Linux</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-37f0e9055bec4a05b11eef7795e8887a" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "f2cufy6wRfA", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_37f0e9055bec4a05b11eef7795e8887a/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V012300_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:f2cufy6wRfA", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_37f0e9055bec4a05b11eef7795e8887a/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_37f0e9055bec4a05b11eef7795e8887a/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-37f0e9055bec4a05b11eef7795e8887a" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-37f0e9055bec4a05b11eef7795e8887a"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-37f0e9055bec4a05b11eef7795e8887a" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-37f0e9055bec4a05b11eef7795e8887a">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-37f0e9055bec4a05b11eef7795e8887a" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-37f0e9055bec4a05b11eef7795e8887a">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V012300_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_37f0e9055bec4a05b11eef7795e8887a/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_521c1b7183a74232a0385cb38f192e71" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/d7c20472645849d7b744570242036df9"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_d7c20472645849d7b744570242036df9" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h1>Downloading and installing the virtual machine</h1> <ol> <li><span style="font-size: 1em; line-height: 1.6em;">Create a custom directory (e.g., for windows users <span style="font-family: terminal, monaco;">c:\users\marco\myvagrant</span> or for Mac/Linux users <span style="font-family: terminal, monaco;">/home/marco/myvagrant</span>)<br />(Please note:&nbsp;<a href="http://docs.vagrantup.com/v2/other/environmental-variables.html" target="_blank">VAGRANT_HOME</a></span>&nbsp;can be set to change the directory where Vagrant stores global state. By default, this is set to '.vagrant.d' under your user profile. This is where boxes (base VMs) are stored, so it can actually be&nbsp;quite large on disk - please make sure you have enough space)</li> <li>Download this <a href="https://github.com/spark-mooc/mooc-setup/archive/master.zip" target="[object Object]">file</a>&nbsp;(https://github.com/spark-mooc/mooc-setup/archive/master.zip) to the custom directory and unzip it.</li> <li>From the unzipped file, copy <span style="font-family: terminal, monaco;">Vagrantfile</span> to the custom directory you created in step #1 (<em>NOTE: It must be named exactly "</em><span style="font-family: terminal, monaco;">Vagrantfile</span><em>" with no extension</em>)</li> <li>Open a DOS prompt (Windows) or Terminal (Mac/Linux), change to the custom directory, and issue the command "<span style="font-family: terminal, monaco;">vagrant up --provider=virtualbox</span>"</li> </ol> <p>NOTE: On Microsoft Windows you may get a Windows Firewall exception popup regarding "<span style="font-family: terminal, monaco;">vboxheadless</span>".&nbsp; Adding an exception is optional and does not seem to impact the Virtual Machine&nbsp;once it is installed.</p> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS100.1x/video/266672cdfc3948b4ac9474a2c3525d79"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_266672cdfc3948b4ac9474a2c3525d79" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>VM Image for Windows</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-266672cdfc3948b4ac9474a2c3525d79" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_266672cdfc3948b4ac9474a2c3525d79/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V011700_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:W_J7PESoujY", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_266672cdfc3948b4ac9474a2c3525d79/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_266672cdfc3948b4ac9474a2c3525d79/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-266672cdfc3948b4ac9474a2c3525d79" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-266672cdfc3948b4ac9474a2c3525d79"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-266672cdfc3948b4ac9474a2c3525d79" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-266672cdfc3948b4ac9474a2c3525d79">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-266672cdfc3948b4ac9474a2c3525d79" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-266672cdfc3948b4ac9474a2c3525d79">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V011700_DTH.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS100.1x/video/10e80dc29c914be9b7bddda7937ad8a2"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_10e80dc29c914be9b7bddda7937ad8a2" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>VM Image for Mac OS X</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-10e80dc29c914be9b7bddda7937ad8a2" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_10e80dc29c914be9b7bddda7937ad8a2/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013800_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:C5iV_g7sLjc", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_10e80dc29c914be9b7bddda7937ad8a2/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_10e80dc29c914be9b7bddda7937ad8a2/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-10e80dc29c914be9b7bddda7937ad8a2" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-10e80dc29c914be9b7bddda7937ad8a2"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-10e80dc29c914be9b7bddda7937ad8a2" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-10e80dc29c914be9b7bddda7937ad8a2">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-10e80dc29c914be9b7bddda7937ad8a2" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-10e80dc29c914be9b7bddda7937ad8a2">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013800_DTH.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-3" data-id="i4x://BerkeleyX/CS100.1x/video/1c6cf4dddbb9489d969645a15cace5ef"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_1c6cf4dddbb9489d969645a15cace5ef" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>VM Image for Linux</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-1c6cf4dddbb9489d969645a15cace5ef" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "W4pv-3H2LNU", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_1c6cf4dddbb9489d969645a15cace5ef/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V012200_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:W4pv-3H2LNU", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_1c6cf4dddbb9489d969645a15cace5ef/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_1c6cf4dddbb9489d969645a15cace5ef/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-1c6cf4dddbb9489d969645a15cace5ef" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-1c6cf4dddbb9489d969645a15cace5ef"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-1c6cf4dddbb9489d969645a15cace5ef" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-1c6cf4dddbb9489d969645a15cace5ef">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-1c6cf4dddbb9489d969645a15cace5ef" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-1c6cf4dddbb9489d969645a15cace5ef">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V012200_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_1c6cf4dddbb9489d969645a15cace5ef/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-4" data-id="i4x://BerkeleyX/CS100.1x/html/6d78d0314ab34426988e07736b07858f"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_6d78d0314ab34426988e07736b07858f" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <p style="font-size: 16px;">When&nbsp;running "<span style="font-family: terminal, monaco;">vagrant up</span>" again, you may&nbsp;receive the following error:</p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">bsdtar: Error opening archive: Unrecognized archive format</span></p> <p style="font-size: 16px;">The solution is to first use the command:</p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">vagrant box remove sparkmooc/base</span></p> <p style="font-size: 16px;">Then, you can use the "<span style="font-family: terminal, monaco;">vagrant up</span>" command again.</p> </div> </div> <div class="vert vert-5" data-id="i4x://BerkeleyX/CS100.1x/html/249f911b2ff24d66b8588cf271291221"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_249f911b2ff24d66b8588cf271291221" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h2>FAQs for Windows</h2> <p>When you type "<span style="font-family: terminal, monaco;">vagrant up</span>", if you encounter the following error:</p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">Bringing machine 'sparkvm' up with 'virtualbox' provider...</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">There was an error while executing 'VBoxManage', a CLI used by Vagrant&nbsp;for controlling VirtualBox. The command and stderr is shown below.</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">Command: ["list", "hostonlyifs"]</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">Stderr: VBoxManage.exe: error: Failed to create the VirtualBox object!</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">VBoxManage.exe: error: Code E_NOINTERFACE (0x80004002) - No such interface supported (extended info not available)</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">VBoxManage.exe: error: Most likely, the VirtualBox COM server is not running or&nbsp;failed to start.</span></p> <p style="padding-left: 30px;"></p> <p>First, make sure you installed VirtualBox using "Run as Administrator". If you did not, then you should follow the directions in the Installing Virtual Box section to uninstall and reinstall VirtualBox. Second, try starting&nbsp;<span style="font-family: terminal, monaco;">command</span> using "Run as Administrator" (right-click on command and select "Run as Administrtor").</p> </div> </div> <div class="vert vert-6" data-id="i4x://BerkeleyX/CS100.1x/html/fcebde8ee52648d9859a063198b93f49"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_fcebde8ee52648d9859a063198b93f49" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <p style="font-size: 16px;">On Linux, if you encounter the following error message:&nbsp;</p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">SSH:</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">* The following settings shouldn't exist: insert_key</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">vm:</span></p> <p style="padding-left: 30px;"><span style="font-family: terminal, monaco;">* The box 'sparkmooc/base' could not be found.</span></p> <p style="font-size: 16px;">It means that your Vagrant version is out of date.&nbsp;Remove the vagrant install (<span style="font-family: terminal, monaco;">apt-get remove</span>). Then you'll want to download the latest version from the vagrant site:&nbsp;<a href="https://www.vagrantup.com/downloads.html" target="_blank">https://www.vagrantup.com/downloads.html</a>.&nbsp;</p> <p style="font-size: 16px;">Install using the command "<span style="font-family: terminal, monaco;">sudo dpkg -i vagrant.deb</span>" and re-run "<span style="font-family: terminal, monaco;">vagrant up</span>" and it should install correctly.</p> <p></p> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_db0dc6b7fada406a8e4023802a009696" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/4b96012ea15b4b4292e70436aeb87dcd"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_4b96012ea15b4b4292e70436aeb87dcd" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h1>Basic Instructions for Using the Virtual Machine</h1> <ol> <li><span style="font-size: 1em; line-height: 1.6em;">To start the VM, from a DOS prompt (Windows) or Terminal (Mac/Linux), issue the command "<span style="font-family: terminal, monaco;">vagrant up</span>".</span></li> <li>To stop the VM, from a DOS prompt (Windows) or Terminal (Mac/Linux), issue the command "<span style="font-family: terminal, monaco;">vagrant halt</span>". <em>Note: You should always stop the VM before you log off, turn off, or reboot your computer.</em></li> <li>At the end of the course, to erase or delete the VM, from a DOS prompt (Windows) or terminal (Mac/Linux), issue the command "<span style="font-family: terminal, monaco;">vagrant destroy</span>". <strong><em>Warning: If you erase or delete the VM, you will lose any work you have done and data you have saved, and you will have download it again when you use the&nbsp;<span style="line-height: 25.600000381469727px;">"</span><span style="line-height: 25.600000381469727px; font-family: terminal, monaco;">vagrant up</span><span style="line-height: 25.600000381469727px;">" command.</span></em></strong></li> <li><span style="line-height: 25.600000381469727px;">Once the VM is running, to access the notebook, open a web browser to "<a href="http://localhost:8001/" target="_blank">http://localhost:8001/</a>" (on Windows and Mac) or "<a href="http://127.0.0.1:8001/" target="_blank">http://127.0.0.1:8001/</a>" (on Linux).</span></li> </ol> <p><span style="line-height: 25.600000381469727px;">NOTE: In step #4 above, try "<a href="http://localhost:8001/" target="_blank">http://localhost:8001/</a>" first, if that doesn't work, try "<a href="http://127.0.0.1:8001/" target="_blank">http://127.0.0.1:8001/</a>", the proper choice&nbsp;depends on the configuration of your&nbsp;computer. &nbsp;We pre-configuted the virtual machine to by default&nbsp;start the iPython notebook on port 8001. &nbsp;If you are having problems connecting to the notebook (neither of the two links works), you should&nbsp;check the output of the "<span style="font-family: terminal, monaco;">vagrant up</span>" command. It may be the case that&nbsp;there was a conflict on your computer with a program already using port 8001 and a higher port number was automatically&nbsp;used. If this occurs, you should use that port number instead of port 8001, and all the rest of the instructions will be the same.</span></p> <p><span style="line-height: 25.600000381469727px;">The following videos walk you through these basic steps.</span></p> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS100.1x/video/51e921ee350d4b19a780ba58fcd93b69"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_51e921ee350d4b19a780ba58fcd93b69" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Basic Instructions for Using the VM on Windows</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-51e921ee350d4b19a780ba58fcd93b69" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "jeGsIxOcOUM", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_51e921ee350d4b19a780ba58fcd93b69/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V002100_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:jeGsIxOcOUM", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_51e921ee350d4b19a780ba58fcd93b69/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_51e921ee350d4b19a780ba58fcd93b69/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-51e921ee350d4b19a780ba58fcd93b69" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-51e921ee350d4b19a780ba58fcd93b69"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-51e921ee350d4b19a780ba58fcd93b69" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-51e921ee350d4b19a780ba58fcd93b69">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-51e921ee350d4b19a780ba58fcd93b69" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-51e921ee350d4b19a780ba58fcd93b69">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V002100_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_51e921ee350d4b19a780ba58fcd93b69/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS100.1x/video/55593b990b9745a98e04e37fada99864"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_55593b990b9745a98e04e37fada99864" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Basic Instructions for Using the VM on Mac OS X</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-55593b990b9745a98e04e37fada99864" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "f23G74ol8xQ", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_55593b990b9745a98e04e37fada99864/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013600_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:f23G74ol8xQ", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_55593b990b9745a98e04e37fada99864/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_55593b990b9745a98e04e37fada99864/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-55593b990b9745a98e04e37fada99864" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-55593b990b9745a98e04e37fada99864"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-55593b990b9745a98e04e37fada99864" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-55593b990b9745a98e04e37fada99864">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-55593b990b9745a98e04e37fada99864" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-55593b990b9745a98e04e37fada99864">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V013600_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_55593b990b9745a98e04e37fada99864/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-3" data-id="i4x://BerkeleyX/CS100.1x/video/482eb5793a834b9c80d7be92c38ad0cc"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_482eb5793a834b9c80d7be92c38ad0cc" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Basic Instructions for Using the VM on Linux</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-482eb5793a834b9c80d7be92c38ad0cc" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "MXHsaTVqHe4", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_482eb5793a834b9c80d7be92c38ad0cc/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V011900_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:MXHsaTVqHe4", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_482eb5793a834b9c80d7be92c38ad0cc/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_482eb5793a834b9c80d7be92c38ad0cc/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-482eb5793a834b9c80d7be92c38ad0cc" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-482eb5793a834b9c80d7be92c38ad0cc"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-482eb5793a834b9c80d7be92c38ad0cc" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-482eb5793a834b9c80d7be92c38ad0cc">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-482eb5793a834b9c80d7be92c38ad0cc" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-482eb5793a834b9c80d7be92c38ad0cc">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V011900_DTH.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_482eb5793a834b9c80d7be92c38ad0cc/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt" role="button" aria-disabled="false">.srt</a> <ol class="a11y-menu-list" role="menu"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt" role="menuitem" aria-disabled="false"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt" role="menuitem" aria-disabled="false"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_41c3737c2a82464aaef6310f99c45ae6" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/e3acde7e074e4023a2cad2f82a80fcc6"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_e3acde7e074e4023a2cad2f82a80fcc6" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h1>Running Your First Notebook</h1> <p>Running your first notebook will test your software setup and environment<span style="font-size: 1em; line-height: 1.6em;">.</span></p> <ol> <li><span style="font-size: 1em; line-height: 1.6em;">If it is not already running, start the Virtual Machine&nbsp;by issuing&nbsp;issue the command "<span style="font-family: terminal, monaco;">vagrant up</span>" from a DOS prompt (Windows) or Terminal (Mac/Linux).</span></li> <li>You should have already downloaded and unzipped the <span style="font-family: terminal, monaco;">master.zip</span> file in the&nbsp;module&nbsp;"<a href="https://courses.edx.org/courses/BerkeleyX/CS100.1x/1T2015/courseware/d1f293d0cb53466dbb5c0cd81f55b45b/920d3370060540c8b21d56f05c64bdda/" target="[object Object]">Downloading and installing the virtual machine</a>".&nbsp; The zip file contains the file "<span style="font-family: terminal, monaco;">lab0_student.ipynb</span>" that you will need in step #4.&nbsp; You can view a read-only online version of the Spark iPython notebook&nbsp;<a href="http://nbviewer.ipython.org/github/spark-mooc/mooc-setup/blob/master/lab0_student.ipynb" target="_blank">here</a>.</li> <li>Once the Virtual Machine&nbsp;is running, access the Jupyter web UI for running IPython notebooks by navigating your web browser to "<a href="http://localhost:8001" target="_blank"><span style="font-family: terminal, monaco;">http://localhost:8001</span></a>" (or "<a href="http://127.0.0.1:8001/" target="[object Object]">http://127.0.0.1:8001/</a>").</li> <li>On the Jupyter web page, use the Upload button to upload the "<span style="font-family: terminal, monaco;">lab0_student.ipynb</span>" Spark iPython notebook file that was mentioned&nbsp;in step #2.</li> <li>Select the file and run each cell - verify that you do not encounter any errors.&nbsp;</li> <li>At the end of the notebook,&nbsp;instructions are included on how to export the notebook as a Python (.py) file and to&nbsp;submit that file to the autograder.</li> </ol> <p><span style="line-height: 1.6; font-size: 1em;">The following videos walk you through the steps of running your first notebook.</span></p> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS100.1x/video/345492fdf2aa4c13a383b1cb81670b0a"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_video;_345492fdf2aa4c13a383b1cb81670b0a" data-type="Video" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Running Your First Notebook</h2> <div id="video_i4x-BerkeleyX-CS100_1x-video-345492fdf2aa4c13a383b1cb81670b0a" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_345492fdf2aa4c13a383b1cb81670b0a/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V014000_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:yDFoeud3uUI", "saveStateUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_345492fdf2aa4c13a383b1cb81670b0a/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_video;_345492fdf2aa4c13a383b1cb81670b0a/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-345492fdf2aa4c13a383b1cb81670b0a" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-BerkeleyX-CS100_1x-video-345492fdf2aa4c13a383b1cb81670b0a"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-BerkeleyX-CS100_1x-video-345492fdf2aa4c13a383b1cb81670b0a" href="#after-transcript_i4x-BerkeleyX-CS100_1x-video-345492fdf2aa4c13a383b1cb81670b0a">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_i4x-BerkeleyX-CS100_1x-video-345492fdf2aa4c13a383b1cb81670b0a" href="#before-transcript_i4x-BerkeleyX-CS100_1x-video-345492fdf2aa4c13a383b1cb81670b0a">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/BERCS100/BERCS100T115-V014000_DTH.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-2" data-id="i4x://BerkeleyX/CS100.1x/html/c0a77ec463c64b1992eb4cd1e09cbae7"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_c0a77ec463c64b1992eb4cd1e09cbae7" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <p>If you encounter an error when running the second test, such as:</p> <pre class="prettyprint" style="padding: 10px; font-family: Monaco, Menlo, Consolas, 'Courier New', monospace; font-size: 13px; color: rgb(51, 51, 51); border-radius: 5px; margin: 8px; line-height: 16.25px; word-break: break-all; border: 1px solid rgb(198, 201, 204); -webkit-box-shadow: rgb(214, 217, 220) 0px 1px 2px; box-shadow: rgb(214, 217, 220) 0px 1px 2px; -webkit-background-clip: padding-box; background-image: -webkit-linear-gradient(top, rgb(248, 248, 249) 0%, rgb(236, 240, 243) 100%); background-attachment: initial; background-size: initial; background-origin: padding-box; background-clip: padding-box; background-position: initial; background-repeat: initial;"><span class="typ" style="color: rgb(102, 0, 102);">Py4JJavaError</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="typ" style="color: rgb(102, 0, 102);">Traceback</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="pun" style="color: rgb(102, 102, 0);">(</span><span class="pln" style="color: rgb(0, 0, 0);">most recent call </span><span class="kwd" style="color: rgb(0, 0, 136);">last</span><span class="pun" style="color: rgb(102, 102, 0);">)</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="pun" style="color: rgb(102, 102, 0);">&lt;</span><span class="pln" style="color: rgb(0, 0, 0);">ipython</span><span class="pun" style="color: rgb(102, 102, 0);">-</span><span class="pln" style="color: rgb(0, 0, 0);">input</span><span class="pun" style="color: rgb(102, 102, 0);">-</span><span class="lit" style="color: rgb(0, 102, 102);">2</span><span class="pun" style="color: rgb(102, 102, 0);">-</span><span class="lit" style="color: rgb(0, 102, 102);">5453bfa2d105</span><span class="pun" style="color: rgb(102, 102, 0);">&gt;</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="kwd" style="color: rgb(0, 0, 136);">in</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="str" style="color: rgb(0, 136, 0);">&lt;module&gt;</span><span class="pun" style="color: rgb(102, 102, 0);">()</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="lit" style="color: rgb(0, 102, 102);">6</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="lit" style="color: rgb(0, 102, 102);">7</span><span class="pln" style="color: rgb(0, 0, 0);"> rawData </span><span class="pun" style="color: rgb(102, 102, 0);">=</span><span class="pln" style="color: rgb(0, 0, 0);"> sc</span><span class="pun" style="color: rgb(102, 102, 0);">.</span><span class="pln" style="color: rgb(0, 0, 0);">textFile</span><span class="pun" style="color: rgb(102, 102, 0);">(</span><span class="pln" style="color: rgb(0, 0, 0);">fileName</span><span class="pun" style="color: rgb(102, 102, 0);">)</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="pun" style="color: rgb(102, 102, 0);">----&gt;</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="lit" style="color: rgb(0, 102, 102);">8</span><span class="pln" style="color: rgb(0, 0, 0);"> shakespeareCount </span><span class="pun" style="color: rgb(102, 102, 0);">=</span><span class="pln" style="color: rgb(0, 0, 0);"> rawData</span><span class="pun" style="color: rgb(102, 102, 0);">.</span><span class="pln" style="color: rgb(0, 0, 0);">count</span><span class="pun" style="color: rgb(102, 102, 0);">()</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="lit" style="color: rgb(0, 102, 102);">9</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="lit" style="color: rgb(0, 102, 102);">10</span><span class="pln" style="color: rgb(0, 0, 0);"> </span><span class="kwd" style="color: rgb(0, 0, 136);">print</span><span class="pln" style="color: rgb(0, 0, 0);"> shakespeareCount</span></pre> <p>This error is likely due to uploading the lab0 ipynb file into the data directory instead of the home (parent) directory. Try uploading the file into the home directory and running the notebook again.</p> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_vertical;_becab56ac25a4916ab6ac1926ae93ea2" data-block-type="vertical" data-course-id="BerkeleyX/CS100.1x/1T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://BerkeleyX/CS100.1x/html/4b4589fa98b7455ebca9dca5b109932d"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_html;_4b4589fa98b7455ebca9dca5b109932d" data-type="HTMLModule" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h2><span style="color: #4c4c4c; font-family: 'Open Sans', 'Helvetica Neue', Helvetica, Arial, sans-serif; line-height: 23.68000030517578px;">The Course Autograder</span></h2> <p style="font-size: 16px;"><span color="#4c4c4c" face="Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif" style="color: #4c4c4c; font-family: 'Open Sans', 'Helvetica Neue', Helvetica, Arial, sans-serif;"><span style="line-height: 23.68000030517578px;">Assignments in this course are automatically graded using an autograder, which runs in the cloud on Amazon EC2. The autograder uses automatic scaling to handle large increases in the number of submissions.</span></span></p> <h2><span color="#4c4c4c" face="Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif" style="color: #4c4c4c; font-family: 'Open Sans', 'Helvetica Neue', Helvetica, Arial, sans-serif;"><span style="line-height: 23.68000030517578px;">SUBMISSION FORMAT</span></span></h2> <p style="font-size: 16px;"><span>Because we are using an autograder, it is very important that your submissions comply with the following rules:</span></p> <ul></ul> <ul> <li><span style="line-height: 25.600000381469727px; font-size: 1em;">Only use the following libraries: standard python libraries, numpy, pyspark, and test_helper (the autograder library).</span></li> <li><span style="line-height: 25.600000381469727px;">Don't leave in extraneous code, as the autograder will timeout if a submission takes too long.</span></li> <li><span style="color: #3d3c40; font-family: 'Open Sans', Verdana, Arial, Helvetica, sans-serif; font-size: 15px; line-height: 22px;">Only change sections of code where you see &lt;FILL IN&gt;, as changing other parts of the code, including directory paths, may cause the code to fail the autograder's tests.</span></li> </ul> <h2>AUTOGRADER RESPONSE TIME</h2> <p style="font-size: 16px;"><span color="#4c4c4c" face="Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif" style="color: #4c4c4c; font-family: 'Open Sans', 'Helvetica Neue', Helvetica, Arial, sans-serif;"><span style="line-height: 23.68000030517578px;">When you submit an assignment to be graded, you can expect to see a graded response within a few&nbsp;minutes. Note that th</span></span>e scale-up process itself can take a few minutes when many users simultaneously submit their assignments, so you may see additional delays in grading. If you do not receive feedback from the autograder server within 1 hour, please resubmit your code. &nbsp;If you not receive feedback on your resubmitted code within 30 minutes, please use the&nbsp;<a href="https://piazza.com/edx_berkeley/summer2015/cs1001x" target="_blank">Piazza discussion group</a>&nbsp;to contact the TAs for support.</p> <p style="font-size: 16px;">Note: The autograder server cluster checks the submission volume (numbers of submissions) every five minutes. &nbsp;If necessary, the autograder launches additional instances to handle the volume.&nbsp;</p> <h2>Autograder FEEDBACK</h2> <p style="font-size: 16px;">There are 3 types of feedback.</p> <ul> <li><em>All tests passed or some tests failed</em>. &nbsp;The result for each test will be in the feedback.</li> <li><em>Timeout</em>. &nbsp;The submitted code took too long to execute. &nbsp;In this case, please optimize your code's running time.</li> <li><em>Abnormal results are detected</em>. &nbsp;In this case, please review your code carefully according to the guidelines found on this page. If you need help with your code, please use the&nbsp;<a href="https://piazza.com/edx_berkeley/summer2015/cs1001x" target="_blank" style="line-height: 25.600000381469727px;">Piazza discussion group</a><span style="line-height: 25.600000381469727px;">&nbsp;to contact the TAs for support.</span></li> </ul> </div> </div> <div class="vert vert-1" data-id="i4x://BerkeleyX/CS100.1x/problem/285ddb6f25e3483cb50383def3d17df5"> <div class="xblock xblock-student_view xblock-student_view-problem xmodule_display xmodule_CapaModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="problem" data-request-token="641175b011c111e5a9130a8d6245fa4f" data-runtime-version="1" data-usage-id="i4x:;_;_BerkeleyX;_CS100.1x;_problem;_285ddb6f25e3483cb50383def3d17df5" data-type="Problem" data-course-id="BerkeleyX/CS100.1x/1T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Problem"} </script> <div id="problem_i4x-BerkeleyX-CS100_1x-problem-285ddb6f25e3483cb50383def3d17df5" class="problems-wrapper" data-problem-id="i4x://BerkeleyX/CS100.1x/problem/285ddb6f25e3483cb50383def3d17df5" data-url="/courses/BerkeleyX/CS100.1x/1T2015/xblock/i4x:;_;_BerkeleyX;_CS100.1x;_problem;_285ddb6f25e3483cb50383def3d17df5/handler/xmodule_handler" data-progress_status="none" data-progress_detail="0.0/100.0"></div> </div> </div> </div> </div>
Creative Commons licensed content, with terms as follow: Attribution Noncommercial Share Alike Some Rights Reserved

open